@@ -6,6 +6,7 @@ ConfigDialog::ConfigDialog(QWidget *parent) :
     ui(new Ui::ConfigDialog)
 {
     ui->setupUi(this);
+    setWindowTitle("Effing Configuration");
 }
 
 ConfigDialog::~ConfigDialog()
@@ -56,3 +57,8 @@ void ConfigDialog::set_target_touch(bool value)
     if (value) ui->radio_touch->setChecked(true);
     else ui->radio_full_facebook->setChecked(true);;
 }
+
+void ConfigDialog::on_button_unauthorize_clicked()
+{
+    emit do_unauthorize();
+}
