@@ -23,6 +23,9 @@ public:
     bool is_target_full();
     void set_target_full(bool value);
 
+signals:
+    void do_unauthorize();
+
 private:
     Ui::ConfigDialog *ui;
     bool _tagline_G;
@@ -30,6 +33,10 @@ private:
     bool _target_touch;
     bool _target_full;
     void update_ui();
+
+private slots:
+    void on_button_unauthorize_clicked();
+
 };
 
 #endif // CONFIGDIALOG_H
