@@ -27,7 +27,6 @@
 #include <QtNetwork/QNetworkReply>
 #include <QtScript/QScriptValue>
 #include "settingsmanager.h"
-#include "messagedto.h"
 
 class FbActions : public QObject
 {
@@ -38,13 +37,15 @@ public:
     void set_token(QString token);
 
 signals:
-    void status_available(QString status);
+    void status_available(QVariant status);
     void status_successfully_set();
 
 public slots:
     void request_status();
     void unauthorize();
     void set_status(QString status);
+    void do_configuration();
+    void do_not_implemented();
 
 private:
     QString get_auth_token();
